@@ -1,16 +1,24 @@
 # -*- coding:utf-8 -*-
 
-# This file is part of gcovr <http://gcovr.com/>.
+#  ************************** Copyrights and license ***************************
 #
-# Copyright 2013-2018 the gcovr authors
-# Copyright 2013 Sandia Corporation
-# This software is distributed under the BSD license.
+# This file is part of gcovr 5.0, a parsing and reporting tool for gcov.
+# https://gcovr.com/en/stable
+#
+# _____________________________________________________________________________
+#
+# Copyright (c) 2013-2021 the gcovr authors
+# Copyright (c) 2013 Sandia Corporation.
+# This software is distributed under the BSD License.
+# Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
+# the U.S. Government retains certain rights in this software.
+# For more information, see the README.rst file.
+#
+# ****************************************************************************
 
 import re
 import pytest
 import time
-import sys
-
 from threading import Event
 
 from ..gcov import GcovParser
@@ -256,13 +264,6 @@ GCOV_8_SOURCES = dict(
     nautilus_example=GCOV_8_NAUTILUS,
     gcov_8_example_2=GCOV_8_EXAMPLE_2)
 
-if sys.version_info < (3, 0):
-    GCOV_8_SOURCES = dict(
-        gcov_8_example=GCOV_8_EXAMPLE.decode(),
-        gcov_8_exclude_throw=GCOV_8_EXAMPLE.decode(),
-        nautilus_example=GCOV_8_NAUTILUS.decode(),
-        gcov_8_example_2=GCOV_8_EXAMPLE_2.decode())
-
 GCOV_8_EXPECTED_UNCOVERED_LINES = dict(
     gcov_8_example='33',
     gcov_8_exclude_throw='33',
@@ -305,7 +306,10 @@ def test_gcov_8(capsys, sourcename):
         lines,
         exclude_unreachable_branches=False,
         exclude_throw_branches=exclude_throw_branches,
-        ignore_parse_errors=False)
+        ignore_parse_errors=False,
+        exclude_lines_by_pattern=None,
+        exclude_function_lines=False
+    )
 
     covdata = {
         parser.fname: parser.coverage,
@@ -340,7 +344,9 @@ def test_unknown_tags(capsys, ignore_errors):
             lines,
             exclude_unreachable_branches=False,
             exclude_throw_branches=False,
-            ignore_parse_errors=ignore_errors)
+            ignore_parse_errors=ignore_errors,
+            exclude_lines_by_pattern=None,
+            exclude_function_lines=False)
 
     if ignore_errors:
         run_the_parser()
@@ -380,7 +386,9 @@ def test_pathologic_codeline(capsys):
             lines,
             exclude_unreachable_branches=False,
             exclude_throw_branches=False,
-            ignore_parse_errors=False)
+            ignore_parse_errors=False,
+            exclude_lines_by_pattern=None,
+            exclude_function_lines=False)
 
     out, err = capsys.readouterr()
     assert out == ''
